Improve this Doc View Source

`ngMessageExp` is the same as `ngMessage`, but instead of a static value, it accepts an expression to be evaluated for the message key.

## Directive Info

- This directive creates new scope.
- This directive executes at priority level 1.

## Usage

    <!-- using attribute directives -->
    <ANY ng-messages="expression">
      <ANY ng-message-exp="expressionValue">...</ANY>
    </ANY>

    <!-- or by using element directives -->
    <ng-messages for="expression">
      <ng-message when-exp="expressionValue">...</ng-message>
    </ng-messages>

Click here to learn more about `ngMessages` and `ngMessage`.

### Arguments

Param | Type | Details
--- | --- | ---
ngMessageExp | whenExp | expression | an expression value corresponding to the message key.